==> syncope-3.0.1-source-release.zip: syncope-3.0.1/wa/starter/src/test/java/org/apache/syncope/wa/starter/audit/WAAuditTrailManagerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.wa.starter.audit;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import java.util.Date;
import org.apache.syncope.client.lib.SyncopeClient;
import org.apache.syncope.common.lib.audit.AuditEntry;
import org.apache.syncope.common.rest.api.service.AuditService;
import org.apache.syncope.wa.bootstrap.WARestClient;
import org.apache.syncope.wa.starter.AbstractTest;
import org.apereo.inspektr.audit.AuditActionContext;
import org.junit.jupiter.api.Test;

public class WAAuditTrailManagerTest extends AbstractTest {

    private static AuditService LOGGER_SERVICE;

    private static WARestClient getWaRestClient() {
        WARestClient restClient = mock(WARestClient.class);
        SyncopeClient syncopeClient = mock(SyncopeClient.class);
        LOGGER_SERVICE = mock(AuditService.class);

        when(restClient.getSyncopeClient()).thenReturn(syncopeClient);
        when(syncopeClient.getService(AuditService.class)).thenReturn(LOGGER_SERVICE);

        return restClient;
    }

    @Test
    public void saveAuditRecord() {
        AuditActionContext audit = new AuditActionContext("principal", "resourceOperatedUpon", "actionPerformed",
                "applicationCode", new Date(), "clientIpAddress", "serverIpAddress", "userAgent");
        WAAuditTrailManager auditTrailManager = new WAAuditTrailManager(getWaRestClient());
        auditTrailManager.saveAuditRecord(audit);
        verify(LOGGER_SERVICE).create(any(AuditEntry.class));
    }
}

==> syncope-3.0.14-source-release.zip: syncope-3.0.14/wa/starter/src/test/java/org/apache/syncope/wa/starter/audit/WAAuditTrailManagerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.wa.starter.audit;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import java.util.Date;
import org.apache.syncope.common.lib.audit.AuditEntry;
import org.apache.syncope.common.rest.api.service.AuditService;
import org.apache.syncope.wa.bootstrap.WARestClient;
import org.apache.syncope.wa.starter.AbstractTest;
import org.apereo.inspektr.audit.AuditActionContext;
import org.junit.jupiter.api.Test;

public class WAAuditTrailManagerTest extends AbstractTest {

    private static AuditService LOGGER_SERVICE;

    private static WARestClient getWaRestClient() {
        LOGGER_SERVICE = mock(AuditService.class);

        WARestClient waRestClient = mock(WARestClient.class);
        when(waRestClient.isReady()).thenReturn(Boolean.TRUE);
        when(waRestClient.getService(AuditService.class)).thenReturn(LOGGER_SERVICE);

        return waRestClient;
    }

    @Test
    public void saveAuditRecord() {
        AuditActionContext audit = new AuditActionContext("principal", "resourceOperatedUpon", "actionPerformed",
                "applicationCode", new Date(), "clientIpAddress", "serverIpAddress", "userAgent");
        WAAuditTrailManager auditTrailManager = new WAAuditTrailManager(getWaRestClient());
        auditTrailManager.saveAuditRecord(audit);
        verify(LOGGER_SERVICE).create(any(AuditEntry.class));
    }
}
